@@ -27,7 +27,7 @@ import click
 from click import echo, style, secho, getchar
 from click.termui import strip_ansi
 
-__version__ = '2.1.0'
+__version__ = '2.2.0'
 __author__ = 'Steven Loria'
 __license__ = 'MIT'
 
@@ -63,10 +63,13 @@ THEMES = OrderedDict([
     ('osx', '{hostname}:{dir} {user}$'),
     ('osx_color', '{hostname.blue}:{dir.green} {user.cyan}$'),
 
-    ('pws', '+{now:%I:%M}%'),
+    ('pws', '{TTY.BOLD}+{TTY.YELLOW}{now:%I:%M}{TTY.RESET}%'),
 
     ('robbyrussell', '{r_arrow.red} {dir.cyan} {git_branch.red.paren.git}'),
 
+    ('giddie', '{user.magenta}@{hostname.yellow}|{cwd.green} '
+                'on {git_branch.magenta}\n{TTY.BLUE}±{TTY.RESET}')
+
 ])
 
 
@@ -81,7 +84,7 @@ TESTING = False
 
 
 class Style(object):
-    """Descriptor that adds ANSI styling when accessed."""
+    """Descriptor that adds ANSI styling to a string when accessed."""
 
     def __init__(self, **kwargs):
         self.kwargs = kwargs
@@ -140,6 +143,38 @@ class TermString(unicode):
             return TermString('\b')
 
 
+class ANSICode(object):
+    """Descriptor that returns the ANSI code the given styles passed to
+    the constructor.
+    """
+
+    def __init__(self, **styles):
+        self.styles = styles
+
+    def __get__(self, instance, owner):
+        reset = self.styles.pop('reset', False)
+        return style('', reset=reset, **self.styles)
+
+
+class TTY(object):
+    """Namespace for all ANSI escape sequences provided by click."""
+
+    BLUE = ANSICode(fg='blue')
+    MAGENTA = ANSICode(fg='magenta')
+    RED = ANSICode(fg='red')
+    WHITE = ANSICode(fg='white')
+    GREEN = ANSICode(fg='green')
+    BLACK = ANSICode(fg='black')
+    YELLOW = ANSICode(fg='yellow')
+    CYAN = ANSICode(fg='cyan')
+    RESET = click.termui._ansi_reset_all
+
+    BOLD = ANSICode(bold=True)
+    BLINK = ANSICode(blink=True)
+    UNDERLINE = ANSICode(underline=True)
+    DIM = ANSICode(dim=True)
+
+
 def get_current_git_branch():
     command = ['git', 'symbolic-ref', '--short', '-q', 'HEAD']
     try:
@@ -175,6 +210,8 @@ def get_prompt_state():
         'dollar': DOLLAR,
         'percent': PERCENT,
         'now': dt.datetime.now(),
+        # ANSI values object
+        'TTY': TTY,
     }
 
 
@@ -311,10 +348,7 @@ class PythonPlayerConsole(InteractiveConsole):
         prompt = sys.ps1
         for command in self.commands:
             try:
-                if more:
-                    prompt = sys.ps2
-                else:
-                    prompt = sys.ps1
+                prompt = sys.ps2 if more else sys.ps1
                 try:
                     magictype(command, prompt_template=prompt, speed=self.speed)
                 except EOFError:
@@ -501,6 +535,7 @@ def preview_themes():
         echo(' command arg1 arg2 ... argn')
         echo()
 
+
 def list_themes():
     secho('Available themes:', bold=True)
     echo(' '.join(THEMES.keys()))
@@ -545,6 +580,7 @@ def _compose(*functions):
 player_command = _compose(SHELL_OPTION, SPEED_OPTION, PROMPT_OPTION)
 recorder_command = _compose(SHELL_OPTION, PROMPT_OPTION, ALIAS_OPTION, ENVVAR_OPTION)
 
+
 @player_command
 @click.argument('session_file', type=click.File('r', encoding='utf-8'))
 @cli.command()
@@ -579,6 +615,8 @@ HEADER_TEMPLATE = """# Recorded with the doitlive recorder
 STOP_COMMAND = 'stop'
 PREVIEW_COMMAND = 'P'
 UNDO_COMMAND = 'U'
+HELP_COMMANDS = ['H', 'help']
+
 
 def echo_rec_buffer(commands):
     if commands:
@@ -588,6 +626,7 @@ def echo_rec_buffer(commands):
     else:
         echo('No commands in buffer.')
 
+
 def run_recorder(shell, prompt, aliases=None, envvars=None):
     commands = []
     prefix = '(' + style('REC', fg='red') + ') '
@@ -612,13 +651,29 @@ def run_recorder(shell, prompt, aliases=None, envvars=None):
             console.interact()
             commands.extend(console.commands)
             commands.append('```\n\n')
+        elif command in HELP_COMMANDS:
+            print_recorder_instructions()
         else:
             commands.append(command + '\n\n')
             run_command(command, shell=shell,
-                aliases=aliases, envvars=envvars, test_mode=TESTING)
+                        aliases=aliases, envvars=envvars, test_mode=TESTING)
     return commands
 
 
+def print_recorder_instructions():
+    echo()
+    echo('INSTRUCTIONS:')
+    echo('Enter ' + style('{}'.format(STOP_COMMAND), bold=True) +
+        ' when you are done recording.')
+    echo('To preview the commands in the buffer, enter {}.'
+        .format(style(PREVIEW_COMMAND, bold=True)))
+    echo('To undo the last command in the buffer, enter {}.'
+        .format(style(UNDO_COMMAND, bold=True)))
+    echo('To view this help message again, enter {}.'
+        .format(style(HELP_COMMANDS[0], bold=True)))
+    echo()
+
+
 @recorder_command
 @click.argument('session_file', default='session.sh',
     type=click.Path(dir_okay=False, writable=True))
@@ -639,16 +694,7 @@ def record(session_file, shell, prompt, alias, envvar):
     secho('RECORDING SESSION: {}'.format(filename),
         fg='yellow', bold=True)
 
-    # Instructions
-    echo()
-    echo('INSTRUCTIONS:')
-    echo('Enter ' + style('{}'.format(STOP_COMMAND), bold=True) +
-        ' when you are done recording.')
-    echo('To preview the commands in the buffer, enter {}.'
-        .format(style(PREVIEW_COMMAND, bold=True)))
-    echo('To undo the last command in the buffer, enter {}.'
-        .format(style(UNDO_COMMAND, bold=True)))
-    echo()
+    print_recorder_instructions()
 
     click.pause()
     click.clear()
